Metrics 
================

.. contents::
    :depth: 2
    :local:

.. currentmodule:: cr.nimble


Error
--------------

.. autosummary::
    :toctree: _autosummary

    mean_squared
    mean_squared_error
    root_mean_squared
    root_mse
    normalized_root_mse


SNR
-------------

.. autosummary::
    :toctree: _autosummary

    peak_signal_noise_ratio
    signal_noise_ratio
